@@ -1,5 +1,5 @@
 #coding = utf-8
-__version__ = '0.4.3'
+__version__ = '0.5.0'
 
 import random
 from termcolor import colored, cprint
@@ -10,13 +10,10 @@ import os
 import json
 import getpass
 import uuid
-from Morpion.datas import variables, loading, setGrid, getPlayers, notDone, isWinner 
-
-
+from datas import variables, loading, setGrid, getPlayers, notDone, isWinner
 
 pathToScript = os.path.dirname(os.path.abspath(__file__))
 
-
 def pathToSave()->str:
     if platform.system() == 'Windows':
         usr = str(getpass.getuser())
@@ -26,71 +23,71 @@ def pathToSave()->str:
     else:
         return f"/Users/{getpass.getuser()}/PCCorp"
 
-print(__name__)
-
-
+global lang
+lang = {}
+with open(f"{pathToScript}/langues.json") as langages:
+    lang = json.load(langages)
 
+l= "en"
 
 vars = variables()
 colors = vars.colors
 cases = vars.scheme
 title = vars.title
-commands = {"Windows": ["cls", "exit", "python -m Morpion"], "Linux":["clear", "exit", """
-        python3 -m Morpion
-        """], "Darwin": ["clear", "", """
-        python3 -m Morpion
-        """] }
+commands = {"Windows": ["cls", "exit", "python -m Morpion"], 
+            "Linux":["clear", "exit", """python3 -m Morpion"""],
+            "Darwin": ["clear", "", """python3 -m Morpion"""] }
 
 sys = platform.system()
 
-
-
 global joueurs
 joueurs = []
 
-
-
 global Player1
 Player1 = colored("X", colors[2])
 global Player2
-Player2 = colored("O", colors[0])
-
-
+Player2 = colored("O", colors[0])   
 
 global coup
 coup = 0
 
 global casesDispo
 casesDispo = []
-
             
-def getCoup(p, casesDispo) -> int:
+def getCoup(p, casesDispo, l) -> int:
+    
+    global lang
     coup = "test"
     while not str(coup) in str(casesDispo):
-        coup = input(f'{p}, quelle case veux-tu marquer ?  ')
+        isError = False
+        coup = input(f'{p}, {lang[l][23]}  ?\n -> ')
         if coup == "":
             coup = "lol"
         try:
             coup = int(coup)
         except ValueError:
-            print('Choisi une case disponible (numéros visibles)')
+            isError = True
+            print(lang[l][24])
             pass
+        
+        if not isError:
+            print(lang[l][24])
+
     return coup 
-    
-    
-
-
-def setGame(joueurs, gameManager):
 
+def setGame(joueurs, gameManager, l):
+    global lang
     for p in gameManager['currentPlayers']:
         joueurs.append(p)
-    grid = setGrid(1, 0, 0)
+    grid = setGrid(1, 0, 0, lang, l)
     os.system(commands[sys][0])
     for ligne in grid:
         print(ligne)
-    game(joueurs, gameManager)
+    game(joueurs, gameManager, l)
 
-def game(joueurs, gameManager):
+def game(joueurs, gameManager, l):
+
+    global lang
     casesDispo = [1, 2, 3, 4, 5, 6, 7, 8, 9] 
     turn = 1
     p1 = random.choice(joueurs)
@@ -105,7 +102,7 @@ def game(joueurs, gameManager):
         else:
             p = p2
         
-        coup = getCoup(p, casesDispo)
+        coup = getCoup(p, casesDispo, l)
         try:
             casesDispo.remove(coup)
         except ValueError:
@@ -113,9 +110,9 @@ def game(joueurs, gameManager):
         #print(casesDispo)
         
         if turn%2 == 1:
-            newGrid = setGrid(turn, coup, Player1)
+            newGrid = setGrid(turn, coup, Player1, lang, l)
         else:
-            newGrid = setGrid(turn, coup, Player2)
+            newGrid = setGrid(turn, coup, Player2, lang, l)
         os.system(commands[sys][0])
         for ligne in newGrid:
             print(ligne)
@@ -139,59 +136,67 @@ def game(joueurs, gameManager):
         trun = 9
     else: 
         turn = 11
-    EndScreen(turn, gameManager, p1, p2, p)
+    EndScreen(turn, gameManager, p1, p2, p, True, l)
 
-
-
-def eraseDatas(turn, gameManager, p1, p2, p):
+def eraseDatas(turn, gameManager, p1, p2, p, l):
+    global lang
     captcha = str(uuid.uuid4())
     captcha = captcha[:5]
-    print('recopier les caractères suivants pour confirmer : ' + captcha)
+    print(lang[l][0] + captcha)
     
     a = input('-> ')
     if a == captcha:
         gameManager = {"# Error 509 TroubleShooter" : "debug"}
         with open(f'{pathToSave()}/save.json', 'w', encoding='utf-8') as file:
             json.dump(gameManager, file)
-            print('Données éffacées ! Le jeu se ferme...')
+            print(lang[l][1])
             time.sleep(1)
-            os.system("p")
+        os.system(commands[sys][2])
     else: 
-        print('Erreur de vérification, réessayez.')
-        EndScreen(turn, gameManager, p1, p2, p)
+        print(lang[l][2])
+        time.sleep(1)
+        EndScreen(turn, gameManager, p1, p2, p, False,l)
+
+def EndScreen(turn, gameManager, p1, p2, p, isEnd, l):
+
+    global lang
+    tprint('Game over')
+
 
-def EndScreen(turn, gameManager, p1, p2, p):
     p1stats = gameManager[str(p1)]
     
     p2stats = gameManager[str(p2)]
-    tprint('Game over')
-    if turn == 11:
-        p1stats[2] = p1stats[2] + 1
-        p2stats[2] = p2stats[2] + 1
-        cprint('Match nul, bien joué à tous les deux !', 'yellow')
-    elif p == p1:
-        p1stats[0] = p1stats[0] + 1
-        p2stats[1] = p2stats[1] + 1
-        print(colored(f"Félicitation {p}, tu as gagné ! ", 'yellow'))
-    elif p == p2:
-        p1stats[1] = p1stats[1] + 1
-        p2stats[0] = p2stats[0] + 1
-        print(colored(f"Félicitation {p}, tu as gagné ! ", 'yellow'))
-    
-    gameManager[p1] = p1stats
-    gameManager[p2] = p2stats
 
-    with open(f'{pathToSave()}/save.json', 'w', encoding='utf-8') as file:
-        json.dump(gameManager, file)
+    if turn == 11:
+        if isEnd:
+            p1stats[2] = p1stats[2] + 1
+            p2stats[2] = p2stats[2] + 1
+        cprint(lang[l][3], 'yellow')
+    elif p == p1:
+        if isEnd:
+            p1stats[0] = p1stats[0] + 1
+            p2stats[1] = p2stats[1] + 1
+        print(colored(f"{lang[l][4]} {p}, {lang[l][5]} ! ", 'yellow'))
+    elif p == p2:
+        if isEnd:
+            p1stats[1] = p1stats[1] + 1
+            p2stats[0] = p2stats[0] + 1
+        print(colored(f"{lang[l][4]} {p}, {lang[l][5]} ! ", 'yellow'))
+    if isEnd:
+        gameManager[p1] = p1stats
+        gameManager[p2] = p2stats
+
+        with open(f'{pathToSave()}/save.json', 'w', encoding='utf-8') as file:
+            json.dump(gameManager, file)
 
     print(colored(f"\nSTATS :\n", 'red'))   
-    print(f"{p1} : {p1stats[0]} victoires, {p1stats[1]} défaites, {p1stats[2]} matchs nuls   ")
-    print(f"{p2} : {p2stats[0]} victoires, {p2stats[1]} défaites, {p2stats[2]} matchs nuls   ")
-    print("\nVoulez vous rejouer ?")
-    print("1) Quitter le jeu")
-    print("2) Rejouer")
-    print("3) Changer de joueurs") 
-    print("4) Paramètres") 
+    print(f"{p1} : {p1stats[0]} {lang[l][6]}, {p1stats[1]} {lang[l][7]}, {p1stats[2]} {lang[l][8]}   ")
+    print(f"{p2} : {p2stats[0]} {lang[l][6]}, {p2stats[1]} {lang[l][7]}, {p2stats[2]} {lang[l][8]}   ")
+    print(f"\n{lang[l][9]}")
+    print(f"1) {lang[l][10]}")
+    print(f"2) {lang[l][11]}")
+    print(f"3) {lang[l][12]}") 
+    print(f"4) {lang[l][13]}") 
 
     def endGameChoice() -> str:
         choice = input("")
@@ -201,25 +206,27 @@ def EndScreen(turn, gameManager, p1, p2, p):
             return endGameChoice()
     mode = int(endGameChoice())
     if mode == 1:
+        os.system(commands[sys][0])
+        tprint(lang[l][25])
         quit()
     elif mode == 2:
-        setGame([], gameManager)
+        setGame([], gameManager, l)
 
     elif mode ==3 :
         os.system(commands[sys][0])
         players = []
-        temp = getPlayers(pathToSave())
+        temp = getPlayers(pathToSave(), lang , l)
         for p in temp.keys():
             players.append(p)
-        setGame(players, gameManager)
+        setGame(players, gameManager, l)
     
     elif mode == 4:
         os.system(commands[sys][0])
-        tprint('Settings')
-        print("\nQue voulez-vous faire ?")
-        print("1) Effacer les sauvegardes")
-        print("2) Changer de Langue - pas encore disponible") 
-        print("3) Retour") 
+        tprint(f'{lang[l][13]}')
+        print(f"\n{lang[l][9]}")
+        print(f"1) {lang[l][14]}")
+        print(f"2) {lang[l][15]}") 
+        print(f"3) {lang[l][16]}") 
 
         def endGameChoice() -> str:
             choice = input("")
@@ -229,13 +236,47 @@ def EndScreen(turn, gameManager, p1, p2, p):
                 return endGameChoice()
         mode = int(endGameChoice())
         if mode == 1:
-            eraseDatas(turn, gameManager, p1, p2, p)
-        if mode == 2:
-            pass
+            eraseDatas(turn, gameManager, p1, p2, p, l)
+        elif mode == 2:
+            setLang(turn, gameManager, p1, p2, p, True, l)
+        else:
+            EndScreen(turn, gameManager, p1, p2, p, False, l)
+
+def setLang(turn, gameManager, p1, p2, p, isEnd, l):
+    os.system(commands[sys][0])
+    tprint('language selection')
+    print('1) English (default)')
+    print('2) Français')
+    print(f"3) {lang[l][16]}")
+    print("Note that if your selection doesn't exist, the language will be set on English.")
+
+    entry = input('\n-> ')
+    
+
+
+    if entry == "2":
+        entry = 'fr'
+        l = 'fr'
+        with open(pathToSave()+"/langage.txt", "w") as output:
+            output.write('fr')
+
+    elif entry == "3":
+        pass
+    else: 
+        entry == 'en'
+        l = 'en'
+        with open(pathToSave()+"/langage.txt", "w") as output:
+            output.write('en')
+    
+    if isEnd == True:
+        print(l)
+        EndScreen(turn, gameManager, p1, p2, p, False, l)
 
 def isFirst():
+
+    global lang
     try:
-        with open(pathToSave()+"/save.json", "r"):
+        with open(pathToSave()+"/langage.txt", "r"):
             pass
     except FileNotFoundError:
         tprint('First use, initializing filesystem...')
@@ -248,17 +289,24 @@ def isFirst():
         json.dump(debugDatas, save)
         save.close()
 
-
+        langage = open(pathToSave()+"/langage.txt", "w")
+        os.system(commands[sys][0])
+        langage.write('en')
+        langage.close()
+        setLang(None, None, None, None, None, False, l)
 
 if __name__ == "__main__":
 
     isFirst()
+
+    with open(pathToSave()+"/langage.txt", "r") as currentLang:
+        l = currentLang.read()
+
     os.chdir(pathToScript)
-    loading(__version__, pathToScript, pathToSave())
+    loading(__version__, pathToScript, pathToSave(), lang, l)
     os.system(commands[sys][0])
     #pathToScript = os.path.dirname(os.path.abspath(__file__))
     #print(pathToScript)
-    gameManager = getPlayers(pathToSave())
+    gameManager = getPlayers(pathToSave(), lang, l)
     os.chdir(pathToScript)
-    setGame(joueurs, gameManager)
-    
+    setGame(joueurs, gameManager, l)
